--[[
    Baldrick_DailyQuests by LordFarlander
    Version 1.5.96
    $Revision: 96 $
]]--

--[[
Copyright (c) 2008, LordFarlander
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
]]--

local Baldrick = _G["Baldrick"];

if( not Baldrick ) then
    error( L["%s requires %s"]:format( "Baldrick_DailyQuests", "Baldrick" ) );
    return;
end--if

local L = LibStub( "AceLocale-3.0" ):GetLocale( "Baldrick_DailyQuests" );
local LBZ = LibStub( "LibBabble-Zone-3.0" );

if( LBZ ) then
    LBZ = LBZ:GetUnstrictLookupTable();
end--if

local ZONES = {};
setmetatable( ZONES, {
    __index = function( self, key )
            local returnVal = LBZ and LBZ[key];

            if( not returnVal ) then
                returnVal = L[key];
            end--if
            return returnVal;
        end } );

local NPCS = L;
local OBJECTIVES = L;
local QuestObjectiveComplete = Baldrick.QuestObjectiveComplete;

local function IsTargetAliveAndNotTapped()
    return ( not UnitIsDead( "playertarget" ) ) and
       ( UnitIsTappedByPlayer( "playertarget" ) or ( not UnitIsTapped( "playertarget" ) ) );
end--IsTargetAliveAndNotTapped()

local function IsTargetDead()
    return UnitIsDead( "playertarget" );
end--IsTargetDead()

local function IsPlayerOnTaxi()
    return UnitOnTaxi( "player" );
end--IsPlayerOnTaxi()

local dailyQuests = {
    --[[
        These are the availiable fields; required are marked with a *, optional fields must be nil:
        questIDs: *Either a number with a questID or a table of numbers with questIDs.
        questItems: *A table of items required for the quest.  The one with an index of default is what will show on the button
                    The fields for items are:
                        questItem: the itemID of the item
                        questItemCount: the MINIMUM number required (the comparison will be >= )
        subZones: A string of subzones/zones this quest is valid for.  Zone names will be checked if in a null subzone.
                  Separate entries with |.
        target: String that has the name of a mob that must be the current target.  Separate entries with |.
        addionalEvents: Either a string with the name of an additional event that this quest should be checked when fired,
                        or a table of strings with names.  Events from a library that uses CallBackHandler can be registered for
                        buy using LibraryName:Event syntax.
        func: A function that takes two parameters.  The first parameter is the quest data iself, the second parameter will hold
              the questID being used.  If used this function must return a boolean, true if this quest is valid to show on the button.
        onEVENT: A function that will be ran whenever the event is encountered and the quest is registered for it.
        ]]--
    --Outland
    --Shattered Sun
    --Shattrath
    {
        --The Multiphase Survey
        questIDs = 11880,
        --Multiphase Spectrographic Goggles
        questItems = { default = { questItem = 35233, questItemCount = 1, }, },
        subZones = ZONES["Spirit Fields"] .. "|" .. ZONES["Nagrand"],
        additionalEvents = { "ClosetGnome_WearSet", "ClosetGnome_PartlyWearSet", };
        onClosetGnome_WearSet = "CloseGnomeFunc",
        onClosetGnome_PartlyWearSet = "CloseGnomeFunc",
        onQuest_Complete = "QuestFunc",
        onQuest_Fail = "QuestFunc",
        onQuest_Lost = "QuestFunc",
        onZONE_CHANGED = "ZoneFunc",
        onZONE_CHANGED_NEW_AREA = "ZoneFunc",
        -- Nonstandard stuffs
        lastSet = "";
        CloseGnomeFunc =
            function( quest, set )
                if( set ~= Baldrick.GetQuestName( quest.questIDs ) ) then
                    quest.lastSet = set;
                end--if
            end,
        QuestFunc =
            function( quest, questName, uid )
                if( ClosetGnome and ( uid == quest.questIDs ) and questName and ClosetGnome:HasSet( questName ) and ClosetGnome:IsSetFullyEquipped( questName ) ) then
                    ClosetGnome:WearSet( quest.lastSet );
                end--if
            end,
        ZoneFunc =
            function( quest )
                local questID = quest.questIDs;
                local questName = Baldrick.GetQuestName( questID );

                if( ClosetGnome and questName and Baldrick.HasQuestAndNotComplete( questID ) and ClosetGnome:HasSet( questName ) ) then
                    local subZone = GetSubZoneText();

                    if( quest.subZones:find( subZone ) or ( ( subZone == "" ) and quest.subZones:find( GetRealZoneText() ) ) ) then
                        ClosetGnome:WearSet( questName );
                    else
                        ClosetGnome:WearSet( quest.lastSet );
                    end--if
                end--if
            end,
    },
    {
        --Intercepting the Mana Cells
        --Maintaining the Sunwell Portal
        questIDs = { 11513, 11514, },
        --Bash'ir Phasing Device
        questItems = { default = { questItem = 34248, questItemCount = 1, }, },
        subZones = ZONES["Bash'ir Landing"],
        additionalEvents = { "LibSpecialEvents-Aura-4.0:PlayerBuffGained", "LibSpecialEvents-Aura-4.0:PlayerBuffLost" },
        func =
            function( quest )
                return not LibStub( "LibSpecialEvents-Aura-4.0" ):UnitHasBuff( "player", select( 1, GetItemInfo( quest.questItems.default.questItem ) ) );
            end,
    },
    --Quel'Danas
    {
        --Erratic Behavior
        --Further Conversions
        questIDs = { 11524, 11525, },
        --Attuned Crystal Cores
        questItems = { default = { questItem = 34368, questItemCount = 1, }, },
        target = NPCS["Erratic Sentry"],
        func =
            function()
                return UnitIsDead( "playertarget" ) and
                    ( UnitIsTappedByPlayer( "playertarget" ) or ( not UnitIsTapped( "playertarget" ) ) );
            end,
    },
    {
        --The Sanctum Wards
        --Arm the Wards!
        questIDs = { 11496, 11523, },
        --Mana Remnants
        questItems = { default = { questItem = 34338, questItemCount = 4, }, },
        subZones = ZONES["Sun's Reach Sanctum"],
    },
    {
        --The Battle for the Sun's Reach Armory
        --The Battle Must Go On
        questIDs = { 11538, 11537, },
        --Shattered Sun Banner
        questItems = { default = { questItem = 34414, questItemCount = 1, }, },
        target = NPCS["Emissary of Hate"],
        func =
            function( _, questID )
                return UnitIsDead( "playertarget" ) and
                    ( ( not ( QuestObjectiveComplete( questID, OBJECTIVES["Emissary of Hate impaled"] ) ) ) and
                    ( not ( QuestObjectiveComplete( questID, OBJECTIVES["Emissary of Hate Impaled"] ) ) ) );
            end,
    },
    {
        --Distraction at the Dead Scar
        --The Air Strikes Must Continue
        questIDs = { 11532, 11533, },
        --Arcane Charges
        questItems = { default = { questItem = 34475, questItemCount = 1, }, },
        subZones = ZONES["The Dead Scar"],
        additionalEvents = { "PLAYER_CONTROL_LOST", "PLAYER_CONTROL_GAINED", "TAXIMAP_CLOSED" },
        func = IsPlayerOnTaxi,
    },
    {
        --Disrupt the Greengill Coast
        questIDs = 11541,
        --Orb of Murloc Control
        questItems = { default = { questItem = 34483, questItemCount = 1, }, },
        target = NPCS["Greengill Slave"],
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Know Your Ley Lines
        questIDs = 11547,
        --Astromancer's Crystal
        questItems = { default = { questItem = 34533, questItemCount = 1, }, },
        subZones = ZONES["The Dawning Square"] .. "|" .. ZONES["Dawnstar Village"] .. "|" .. ZONES["Greengill Coast"],
        func =
            function( _, questid )
                local subZone = GetSubZoneText();

                return ( ( subZone == ZONES["The Dawning Square"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Portal Reading Taken"] ) ) ) or
                    ( ( subZone == ZONES["Dawnstar Village"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Bloodcrystal Reading Taken"] ) ) ) or
                    ( ( subZone == ZONES["Greengill Coast"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Shrine Reading Taken"] ) ) );
            end,
    },
    {
        --Intercept the Reinforcements
        --Keeping the Enemy at Bay
        questIDs = { 11542, 11543, },
        --Flaming Oil
        questItems = { default = { questItem = 34489, questItemCount = 1, }, },
        additionalEvents = { "PLAYER_CONTROL_LOST", "PLAYER_CONTROL_GAINED", "TAXIMAP_CLOSED", "ZONE_CHANGED" },
        func =
            function( _, questid )
                return UnitOnTaxi( "player" ) and
                    ( ( not QuestObjectiveComplete( questid, OBJECTIVES["Sin'loren sails burned"] ) ) or
                    ( not QuestObjectiveComplete( questid, OBJECTIVES["Bloodoath sails burned"] ) ) or
                    ( not QuestObjectiveComplete( questid, OBJECTIVES["Dawnchaser sails burned"] ) ) );
            end,
    },
    {
        --Ata'mal Armaments
        questIDs = 11544,
        --Ata'mal Armament
        questItems = { default = { questItem = 34500, questItemCount = 1, }, },
        subZones = ZONES["Sun's Reach Armory"],
    },
    {
        --Discovering Your Roots
        --Rediscovering Your Roots
        questIDs = { 11520, 11521, },
        --Razorthorn Flayer Gland
        questItems = { default = { questItem = 34255, questItemCount = 1, }, },
        target = NPCS["Razorthorn Ravager"],
        func = IsTargetAliveAndNotTapped,
    },
    --Throne of Kil'jaeden
    {
        --Blood for Blood
        questIDs = 11515,
        --Fel Siphon, Demonic Blood
        questItems = { default = { questItem = 34257, questItemCount = 1, }, { questItem = 34259, questItemCount = 1, }, },
        target = NPCS["Felblood Initiate"],
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Blast the Gateway
        questIDs = 11516,
        --Sizzling Embers
        questItems = { default = { questItem = 34253, questItemCount = 1, }, },
        subZones = ZONES["Throne of Kil'jaeden"],
    },

    --Skyguard
    --Skettis
    {
        --Fires Over Skettis
        questIDs = 11008,
        --Skyguard Blasting Charges
        questItems = { default = { questItem = 32406, questItemCount = 1, }, },
        subZones = ZONES["Lower Veil Shil'ak"] .. "|" .. ZONES["Skettis"] .. "|" .. ZONES["Terokk's Rest"] .. "|" .. ZONES["Upper Veil Shil'ak"] .. "|" .. ZONES["Veil Ala'rak"] .. "|" .. ZONES["Veil Harr'ik"],
        additionalEvents = { "LibSpecialEvents-Mount-4.0:Mounted", "LibSpecialEvents-Mount-4.0:Dismounted" },
        func = IsMounted,
    },
    --Blade's Edge Mountains
    {
        --Bombing Run
        --Bomb Them Again!
        questIDs = { 11010, 11102, 11023, },
        --Skyguard Bombs
        questItems = { default = { questItem = 32456, questItemCount = 1, }, },
        subZones = ZONES["Forge Camp: Terror"] .. "|" .. ZONES["Forge Camp: Wrath"],
        additionalEvents = { "LibSpecialEvents-Mount-4.0:Mounted", "LibSpecialEvents-Mount-4.0:Dismounted" },
        func = IsMounted,
    },
    {
        --Wrangle Some Aether Rays!
        --Wrangle More Aether Rays!
        questIDs = { 11065, 11066, },
        --Wrangling Rope
        questItems = { default = { questItem = 32698, questItemCount = 1, }, },
        target = NPCS["Aether Ray"],
        func = IsTargetAliveAndNotTapped,
    },

    --Ogri'la
    {
        --Banish The Demons
        --Banish More Demons
        questIDs = { 11026, 11051, },
        --Banishing Crystal, Apexis Shard
        questItems = { default = { questItem = 32696, questItemCount = 1, }, { questItem = 32569, questItemCount = 1, }, },
        subZones = ZONES["Forge Camp: Terror"] .. "|" .. ZONES["Forge Camp: Wrath"],
    },

    --Netherwing
    {
        --The Booterang: A Cure For The Common Worthless Peon
        questIDs = 11055,
        --Booterang
        questItems = { default = { questItem = 32680, questItemCount = 1, }, },
        target = NPCS["Disobedient Dragonmaw Peon"],
        func = IsTargetAliveAndNotTapped,
    },
    {
        --A Slow Death
        questIDs = 11020,
        --Yarzill's Mutton
        --Fel Gland
        questItems = { default = { questItem = 32503, questItemCount = 1, }, { questItem = 32502, questItemCount = 1, }, },
        subZones = ZONES["Netherwing Ledge"],
    },

    --Northrend
    --Howling Ford
    {
        --Break the Blockade
        questIDs = 11153,
        --Petrov's Cluster Bombs
        questItems = { default = { questItem = 33098, questItemCount = 1, }, },
        subZones = ZONES["Shattered Straits"],
    },
    {
        --Planning for the Future
        questIDs = 11960,
        --Anuniaq's Net
        questItems = { default = { questItem = 40946, questItemCount = 1, }, },
        subZones = ZONES["Howling Fjord"],
    },
    --Coldarra
    {
        --Drake Hunt
        questIDs = 11940,
        --Raelorasz's Spear
        questItems = { default = { questItem = 35506, questItemCount = 1, }, },
        target = NPCS["Nexus Drake Hatchling"],
        func = IsTargetAliveAndNotTapped,
    },
    --Grizzly Hills
    {
        --Life or Death
        questIDs = 12296,
        --Renewing Bandage
        questItems = { default = { questItem = 37576, questItemCount = 1, }, },
        target = NPCS["Wounded Westfall Infantry"],
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Overwhelmed!
        questIDs = 37568,
        --Renewing Tourniquet
        questItems = { default = { questItem = 37576, questItemCount = 1, }, },
        target = NPCS["Wounded Skirmisher"],
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Smoke 'Em Out
        questIDs = { 12323, 12324, },
        --Smoke Bomb
        questItems = { default = { questItem = 37621, questItemCount = 1, }, },
        subZones = ZONES["Venture Bay"],
    },
    {
        --Seared Scourge
        questIDs = { 12029, 12038, },
        --Mack's Dark Grog
        questItems = { default = { questItem = 35908, questItemCount = 1, }, },
        target = NPCS["Famished Scourge Trolls"],
        func = IsTargetAliveAndNotTapped,
    },
    --Zul'Drak
    {
        --Troll Patrol: Done to Death
        questIDs = 12568,
        --Incinerating Oil
        questItems = { default = { questItem = 38556, questItemCount = 1, }, },
        target = NPCS["Defeated Argent Footmen"],
        func = IsTargetDead,
    },
    {
        --Troll Patrol: Can You Dig It?
        questIDs = 12588,
        --Steel Spade
        questItems = { default = { questItem = 38566, questItemCount = 1, }, },
        subZones = ZONES["Drak'Sotra"],
    },
    {
        --Troll Patrol: High Standards
        questIDs = 12502,
        --Argent Crusade Banner
        questItems = { default = { questItem = 38544, questItemCount = 1, }, },
        subZones = ZONES["Drak'Sotra"],
    },
    {
        --Troll Patrol: Throwing Down
        questIDs = 12591,
        --High Impact Grenade
        questItems = { default = { questItem = 38574, questItemCount = 1, }, },
        subZones = ZONES["Drak'Sotra"],
    },
    --Sholazar Basin
    {
        --The Heartblood's Strength
        questIDs = 12732,
        --Rejek's Vial
        questItems = { default = { questItem = 39574, questItemCount = 1, }, },
        subZones = ZONES["Suntouched Pillar"],
    },
    {
        --Chicken Party!
        --Flown the Coop!
        questIDs = { 12702, 12532 },
        --Chicken Net
        questItems = { default = { questItem = 38689, questItemCount = 1, }, },
        target = NPCS["Uncooperative Chicken Escapee"],
        func = IsTargetAliveAndNotTapped,
    },
    {
        --A Hero's Headgear
        questIDs = 12758,
        --Venture Co. Explosives
        questItems = { default = { questItem = 39651, questItemCount = 1, }, },
        target = NPCS["Stormwatcher"],
        func = IsTargetDead,
    },
    {
        --Kartak's Rampage
        questIDs = 12703,
        --Oracle Blood
        questItems = { default = { questItem = 39265, questItemCount = 1, }, },
        subZones = ZONES["Shrine of Kartak"],
    },
    {
        --Power of the Great Ones
        questIDs = 12762,
        --Dormant Polished Crystal
        questItems = { default = { questItem = 39747, questItemCount = 1, }, },
        subZones = ZONES["Sparktouched Haven"],
    },
    {
        --Rejek: First Blood
        questIDs = 12734,
        --Rejek's Blade
        questItems = { default = { questItem = 39577, questItemCount = 1, }, },
        target = NPCS["Ferocious Bristlepine"] .. "|" .. NPCS["Hardnuckle Charger"] .. "|" .. NPCS["Sapphire Hive Wasp"]  .. "|" .. NPCS["Mistwhisper"],
        func =
            function( _, questid )
                local target, _ = UnitName( "playertarget" );

                return UnitIsDead( "playertarget" ) and
                    ( ( ( ( target == NPCS["Ferocious Bristlepine"] ) or ( target == NPCS["Hardnuckle Charger"] ) ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Blade blooded on Ferocious Bristlepine"] ) ) ) or
                    ( ( target == NPCS["Sapphire Hive Wasp"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Blade blooded on Sapphire Hive Wasp"] ) ) ) or
                    ( target:find( NPCS["Mistwhisper"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Blade Blooded on Mistwhisper members"] ) ) ) );
            end,
    },
    {
        --Secret Strength of the Frenzyheart
        questIDs = 12760,
        --Wolvar Berries
        --Thunderbrew's Hard Ale
        questItems = { default = { questItem = 39739, questItemCount = 1, }, { questItem = 39738, questItemCount = 1, }, },
    },
    {
        --Song of Fecundity
        questIDs = 12737,
        --Horn of Fecundity
        questItems = { default = { questItem = 39599, questItemCount = 1, }, },
        subZones = ZONES["Stormwright's Shelf"],
    },
    {
        --Song of Reflection
        questIDs = 12736,
        --Didgeridoo of Contemplation
        questItems = { default = { questItem = 39598, questItemCount = 1, }, },
        subZones = ZONES["Glimmering Pillar"] .. "|" .. ZONES["Suntouched Pillar"] .. "|" .. ZONES["Mosslight Pillar"] .. "|" .. ZONES["Skyreach Pillar"],
        func =
            function( _, questid )
                local subZone = GetSubZoneText();

                return ( ( subZone == ZONES["Glimmering Pillar"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Contemplation at Glimmering Pillar"] ) ) ) or
                    ( ( subZone == ZONES["Suntouched Pillar"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Contemplation at Suntouched Pillar"] ) ) ) or
                    ( ( subZone == ZONES["Mosslight Pillar"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Contemplation at Mosslight Pillar"] ) ) ) or
                    ( ( subZone == ZONES["Skyreach Pillar"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Contemplation at Skyreach Pillar"] ) ) );
            end,
    },
    {
        --Song of Fecundity
        questIDs = 12737,
        --Horn of Fecundity
        questItems = { default = { questItem = 39599, questItemCount = 1, }, },
        subZones = ZONES["Stormwright's Shelf"],
    },
    {
        --Will of the Titans
        questIDs = 12705,
        --Tainted Crystal
        questItems = { default = { questItem = 39266, questItemCount = 1, }, },
        subZones = ZONES["Great Lightning Stone"],
    },
    --The Storm Peaks
    {
        --Blowing Hodir's Horn
        questIDs = 12977,
        --Hodir's Horn
        questItems = { default = { questItem = 42164, questItemCount = 1, }, },
        target = NPCS["Frost Giant Ghost"] .. "|" .. NPCS["Frost Dwarf Ghost"],
        func =
            function( _, questid )
                local target, _ = UnitName( "playertarget" );

                return UnitIsDead( "playertarget" ) and
                    ( ( ( target == NPCS["Frost Giant Ghost"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Giant Spirit Freed"] ) ) ) or
                    ( ( target == NPCS["Frost Dwarf Ghost"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Blade blooded on Sapphire Hive Wasp"] ) ) ) );
            end,
    },
    {
        --Feeding Arngrim
        questIDs = 13046,
        --Arngrim's Tooth
        questItems = { default = { questItem = 42774, questItemCount = 1, }, },
        target = NPCS["Roaming Jormungar"],
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Thrusting Hodir's Spear
        questIDs = 13003,
        --Hodir's Spear
        questItems = { default = { questItem = 42769, questItemCount = 1, }, },
        target = NPCS["Wild Wyrm"],
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Hot and Cold
        questIDs = 12981,
        --Essence of Ice
        questItems = { default = { questItem = 42246, questItemCount = 1, }, },
        subZones = ZONES["Fjorn's Anvil"],
    },
    {
        --Overstock
        questIDs = 12833,
        --Improved Land Mines
        questItems = { default = { questItem = 40676, questItemCount = 1, }, },
        subZones = ZONES["Garm's Bane"],
    },
    {
        --Spy Hunter
        questIDs = 12994,
        --Ethereal Worg's Fang
        questItems = { default = { questItem = 42479, questItemCount = 1, }, },
        subZones = ZONES["Valley of Ancient Winters"],
    },
    --Icecrown
    {
        --From Their Corpses, Rise!
        questIDs = 12813,
        --Darkmender's Tincture
        questItems = { default = { questItem = 40587, questItemCount = 1, }, },
        target = NPCS["Scarlet Onslaught"],
        func = IsTargetDead,
    },
    {
        --Leave Our Mark!
        questIDs = 12995,
        --Ebon Blade Banner
        questItems = { default = { questItem = 42480, questItemCount = 1, }, },
        target = NPCS["Vrykul"],
        func = IsTargetDead,
    },
    {
        --The Solution Solution
        questIDs = 13292,
        --Smuggled Solution, Abandoned Helm, Abandoned Armor, Pile of Bones
        questItems = { default = { questItem = 44048, questItemCount = 1, }, { questItem = 43610, questItemCount = 1, }, { questItem = 43616, questItemCount = 1, }, { questItem = 43609, questItemCount = 1, }, },
        subZones = ZONES["Broken Front"],
    },
    {
        --Volatility
        questIDs = 13261,
        --Copperclaw's Volatile Oil, Abandoned Helm, Abandoned Armor, Pile of Bones
        questItems = { default = { questItem = 43608, questItemCount = 1, }, { questItem = 43610, questItemCount = 1, }, { questItem = 43616, questItemCount = 1, }, { questItem = 43609, questItemCount = 1, }, },
        subZones = ZONES["Broken Front"],                
    },
    {
        --That's Abominable!
        questIDs = { 13264, 13276, 13288, },
        --Abomination Reanimation Kit, Chilled Abomination Guts
        questItems = { default = { questItem = 43968, questItemCount = 1, }, { questItem = 43966, questItemCount = 1, }, },
    },

    --Holiday
    --Midsummer Fire Festival
    {
        --Torch Catching
        --More Torch Catching
        questIDs = { 11657, 11923, 11924, 11925, },
        --Unlit Torches
        questItems = { default = { questItem = 34833, questItemCount = 1, }, },
        holiday = L["Midsummer Fire Festival"],
    },
    {
        --Torch Tossing
        --More Torch Tossing
        questIDs = { 11731, 11922, 11921, 11926, },
        --Practice Torches
        questItems = { default = { questItem = 34862, questItemCount = 1, }, },
        holiday = L["Midsummer Fire Festival"],
    },
    --Brewfest
    {
        --Now This is Ram Racing... Almost.
        --There and Back Again
        --Bark for Drohn's Distillery!
        --Bark for T'chali's Voodoo Brewery!
        --Bark for the Barleybrews!
        --Bark for the Thunderbrews!
        questIDs = { 11318, 11409, 11122, 11412, 11407, 11408, 11293, 11294, },
        --Ram Racing Reins
        questItems = { default = { questItem = 33306, questItemCount = 1, }, },
        holiday = L["Brewfest"],
        additionalEvents = { "LibSpecialEvents-Aura-4.0:PlayerBuffGained", "LibSpecialEvents-Aura-4.0:PlayerBuffLost" },
        func =
            function()
                return LibStub( "LibSpecialEvents-Aura-4.0" ):UnitHasBuff( "player", L["Rental Racing Ram"] );
            end,
    },
    --Hallow's End
    {
        --Fire Brigade Practice
        --Fire Training
        --Stop the Fires!
        --"Let the Fires Come!"
        questIDs = { 11360, 11439, 11440, 11361, 11449, 11450, 11131, 11219, 12135, 12139, },
        --Water Bucket
        questItems = { default = { questItem = 32971, questItemCount = 1, }, },
        holiday = L["Hallow's End"],
    },

    --Cooking
    --Northrend
    {
        --Cheese for Glowergold
        questIDs = { 13103, 13115, },
        --Empty Cheese Serving Platter, Aged Dalaran Cheese, Half Full Wine Glass
        questItems = { default = { questItem = 43139, questItemCount = 1, }, { questItem = 43137, questItemCount = 1, }, { questItem = 43138, questItemCount = 6, }, },
    },
    {
        --Infused Mushroom Meatloaf
        questIDs = { 13100, 13112, },
        --Meatloaf Pan, Infused Mushroom, Chilled Meat
        questItems = { default = { questItem = 43101, questItemCount = 1, }, { questItem = 43100, questItemCount = 4, }, { questItem = 43013, questItemCount = 2, }, },
    },
    {
        --Mustard Dogs!
        questIDs = { 13107, 13116, },
        --Empty Picnic Basket, Rhino Dog, Mustard Herb
        questItems = { default = { questItem = 43142, questItemCount = 1, }, { questItem = 34752, questItemCount = 4, }, { questItem = 43143, questItemCount = 4, }, },
    },
    {
        --Sewer Stew
        questIDs = { 13102, 13114, },
        --Stew Cookpot, Chilled Meat, Crystal Song Carrot
        questItems = { default = { questItem = 43147, questItemCount = 1, }, { questItem = 43013, questItemCount = 4, }, { questItem = 43148, questItemCount = 4, }, },
    },
    --Outland
    {
        --Revenge is Tasty
        questIDs = 11377,
        --Cooking Pot: Kaliri Stew, Giant Kaliri Wing, Warp Burger
        questItems = { default = { questItem = 33837, questItemCount = 1, }, { questItem = 33838, questItemCount = 1, }, { questItem = 27659, questItemCount = 3, }, },
    },
    {
        --Soup for the Soul
        questIDs = 11381,
        --Cooking Pot: Spiritual Soup, Roasted Clefthoof
        questItems = { default = { questItem = 33851, questItemCount = 1, }, { questItem = 27658, questItemCount = 4, }, },
        subZones = ZONES["Ancestral Grounds"],
    },
    {
        --Super Hot Stew
        questIDs = 11379,
        --Cooking Pot: Demon Broiled Surprise, Mok'Nathal Shortribs, Crunchy Serpent
        questItems = { default = { questItem = 33852, questItemCount = 1, }, { questItem = 31672, questItemCount = 2, }, { questItem = 31673, questItemCount = 1, }, },
        target = NPCS["Abyssal Flamebringer"],
        func = IsTargetDead,
    },
};

Baldrick:RegisterQuestModule( L["Daily Quests"], dailyQuests, nil );
